aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEinhard Leichtfuß <alguien@respiranto.de>2022-04-29 14:58:55 +0200
committerEinhard Leichtfuß <alguien@respiranto.de>2022-04-29 14:58:55 +0200
commit915faab9c074a0a30b8321c3836d0b35f475e94d (patch)
tree522b4109f2d43ff06db001b329ec1e09884cf6c8
parent90a0069d9bb72bf3caf59e2411a144f9e3afd2d3 (diff)
Use proper .bash suffix
-rw-r--r--README8
-rw-r--r--TODO2
-rw-r--r--basic.bash (renamed from basic.sh)10
-rw-r--r--general-config.bash (renamed from general-config.sh)2
-rwxr-xr-xmake_install.bash (renamed from make_install.sh)6
-rwxr-xr-xupdate.bash (renamed from update.sh)4
-rw-r--r--user-config.default.bash9
-rw-r--r--user-config.default.sh9
8 files changed, 25 insertions, 25 deletions
diff --git a/README b/README
index 28f088a..1031184 100644
--- a/README
+++ b/README
@@ -6,17 +6,17 @@ Things are to be written here.
Configuration:
--------------
-Copy user-config.default.sh to user-config.sh and set any options to your
+Copy user-config.default.bash to user-config.bash and set any options to your
linking.
Usage:
------
-Make sure user-config.sh exists and has the correct $maintainer variable set.
+Make sure user-config.bash exists and has the correct $maintainer variable set.
-Then, just call ./update.sh or ./make_install.sh. Usage information will be
-displayed.
+Then, just call ./update.bash or ./make_install.bash. Usage information will
+be displayed.
Dependencies:
diff --git a/TODO b/TODO
index 27c294e..1485fa7 100644
--- a/TODO
+++ b/TODO
@@ -16,6 +16,6 @@ TODO file for aur-fd-scripts
* Set up directory structure if not existing.
* [consider] Notify on checksum change (should not happen unless version
numbers change).
-* Add $basedir in user-config.default.sh
+* Add $basedir in user-config.default.bash
* check(): `make validation'
- The .dtd and .rng files would need to be included in the tools package.
diff --git a/basic.sh b/basic.bash
index 5dc475f..643c39d 100644
--- a/basic.sh
+++ b/basic.bash
@@ -2,10 +2,10 @@
#
# Copyright 2018 Einhard Leichtfuß
#
-# basic.sh - script containing the array of the to be generated dictionary's
-# names and some common functionality, mostly wrapping sed.
+# basic.bash - script containing the array of the to be generated dictionary's
+# names and some common functionality, mostly wrapping sed.
#
-# Copyright 2018 Einhard Leichtfuß
+# Copyright 2018,2022 Einhard Leichtfuß
#
# This file is part of aur-fd-scripts
#
@@ -29,8 +29,8 @@
script_path="$(realpath "$0")"
script_dir="${script_path%/*}"
-. "${script_dir}/general-config.sh" || exit 1
-. "${script_dir}/user-config.sh" || exit 1
+. "${script_dir}/general-config.bash" || exit 1
+. "${script_dir}/user-config.bash" || exit 1
function init
diff --git a/general-config.sh b/general-config.bash
index 040ec6a..d9f62d3 100644
--- a/general-config.sh
+++ b/general-config.bash
@@ -2,7 +2,7 @@
#
# Copyright 2018,2022 Einhard Leichtfuß
#
-# general-config.sh - general configuration options
+# general-config.bash - general configuration options
#
# This file is part of aur-fd-scripts
#
diff --git a/user-config.default.bash b/user-config.default.bash
new file mode 100644
index 0000000..a2e0eca
--- /dev/null
+++ b/user-config.default.bash
@@ -0,0 +1,9 @@
+#!/usr/bin/env bash
+#
+# user-config.default.bash - user configuration options;
+# copy this file to user-config.bash and modify to
+# your liking.
+#
+
+# The maintainer to be listed in the PKGBUILD.
+maintainer="Your Name <your@email-address.tld>"
diff --git a/user-config.default.sh b/user-config.default.sh
deleted file mode 100644
index 4675afb..0000000
--- a/user-config.default.sh
+++ /dev/null
@@ -1,9 +0,0 @@
-#!/usr/bin/env bash
-#
-# user-config.default.sh - user configuration options;
-# copy this file to user-config.sh and modify to
-# your liking.
-#
-
-# The maintainer to be listed in the PKGBUILD.
-maintainer="Your Name <your@email-address.tld>"
diff --git a/make_install.sh b/make_install.bash
index 579586a..1df6acb 100755
--- a/make_install.sh
+++ b/make_install.bash
@@ -1,8 +1,8 @@
#!/usr/bin/env bash
#
# make_install.sh - script to create the .install files
#
-# Copyright 2018 Einhard Leichtfuß
+# Copyright 2018,2022 Einhard Leichtfuß
#
# This file is part of aur-fd-scripts
#
@@ -22,7 +22,7 @@
script_path="$(realpath "$0")"
script_dir="${script_path%/*}"
-. "${script_dir}/basic.sh" || exit 1
+. "${script_dir}/basic.bash" || exit 1
function main
@@ -1,8 +1,8 @@
#!/usr/bin/env bash
#
-# make_install.sh - script to create the .install files
+# make_install.bash - script to create the .install files
#
diff --git a/update.sh b/update.bash
index f011164..324dfa1 100755
--- a/update.sh
+++ b/update.bash
@@ -1,6 +1,6 @@
#!/usr/bin/env bash
#
# update.sh - script to check for updates and perform them (on the PKGBUILDs)
#
# Copyright 2018,2022 Einhard Leichtfuß
#
@@ -33,7 +33,7 @@
script_path="$(realpath "$0")"
script_dir="${script_path%/*}"
-. "${script_dir}/basic.sh" || exit 1
+. "${script_dir}/basic.bash" || exit 1
function main
@@ -1,6 +1,6 @@
#!/usr/bin/env bash
#
-# update.sh - script to check for updates and perform them (on the PKGBUILDs)
+# update.bash - script to check for updates and perform them (on the PKGBUILDs)
#
# Copyright 2018,2022 Einhard Leichtfuß